Conduit — Conduit v0.999 documentation

# Conduit

Conduit is a stream transformation library designed to support power engineering analytics. In particular, Conduit integrates deeply with the Berkeley Tree Database (BTrDB) using the btrdb-python bindings to manage stream metadata and apply transformations to individual streams, phasors, phasor pairs, and phasor groups.

## User Guide

The documentation is structured to quickly get you to important concepts and API references. The first part of the documentation covers important concepts and a simple tutorial to get you started quickly. From there, dive deeper into the API reference!

- Installation
  - Installing with pip
  - Installing with Anaconda
- Quick Start

## Indices and tables

- Index

- Module Index

- Search Page